@@ -3,7 +3,7 @@ package Wikibase::Datatype::Print;
 use strict;
 use warnings;
 
-our $VERSION = 0.03;
+our $VERSION = 0.04;
 
 1;
 
@@ -95,15 +95,15 @@ Wikibase property value pretty print helpers.
 
 =item L<Wikibase::Datatype::Print::Value::Quantity>
 
-TODO
+Wikibase quantity value pretty print helpers.
 
 =item L<Wikibase::Datatype::Print::Value::String>
 
-TODO
+Wikibase string value pretty print helpers.
 
 =item L<Wikibase::Datatype::Print::Value::Time>
 
-TODO
+Wikibase time value pretty print helpers.
 
 =back
 
@@ -143,6 +143,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.03
+0.04
 
 =cut
